#
# spec file for package mate-menus
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname  libmate-menu
%define sover   2
%define typelib typelib-1_0-MateMenu-2_0
%define _version 1.20
Name:           mate-menus
Version:        1.20.0
Release:        lp151.3.5.1
Summary:        MATE Desktop Menu
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/GUI/Other
Url:            https://mate-desktop.org/
Source:         http://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
# PATCHES-FIX-UPSTREAM backport series to fix boo#1144346
Patch0:         0001-drop-python2-support.patch
Patch1:         0002-require-gio-unix.patch
Patch2:         0003-require-gio-unix-drop-python-example.patch
Patch3:         0004-use-G_BEGIN-END_DECLS.patch
Patch4:         0005-backport-from-gnome-menus.patch
Patch5:         0006-udpate-examples.patch
BuildRequires:  intltool
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  python-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gio-2.0) >= 2.48
BuildRequires:  pkgconfig(glib-2.0) >= 2.48
BuildRequires:  pkgconfig(gobject-introspection-1.0)
Requires:       %{name}-branding
Recommends:     %{name}-lang

%description
mate-menus contains the libmate-menu library, the layout
configuration files for the MATE menu, as well as a simple menu
editor.

The libmate-menu library implements the "Desktop Menu Specification"
from freedesktop.org.

%package branding-upstream
Summary:        The MATE Desktop Menu -- Upstream Menus Definitions
License:        GPL-2.0-or-later
Group:          System/GUI/Other
Requires:       %{name} = %{version}
Supplements:    packageand(%{name}:branding-upstream)
Conflicts:      otherproviders(%{name}-branding)
Provides:       %{name}-branding = %{version}
BuildArch:      noarch
#BRAND: This package contains set of needed .menu files in
#BRAND: /etc/xdg/menus. .directory files in
#BRAND: %{_datadir}/desktop-directories/Multimedia.directory are part of
#BRAND: the main package. If you need custom one, simply it put there
#BRAND: and modify .menu file to refer to it.

%description branding-upstream
The package contains an implementation of the draft "Desktop Menu
Specification" from freedesktop.org:

http://freedesktop.org/Standards/menu-spec

This package provides the upstream definitions for menus.

%package -n %{soname}%{sover}
Summary:        MATE Desktop Menu
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/Libraries

%description -n %{soname}%{sover}
The libmate-menu library implements the "Desktop Menu Specification"
from freedesktop.org.

%package -n %{typelib}
Summary:        MATE Desktop menu bindings
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/GUI/Other

%description -n %{typelib}
The libmate-menu library implements the "Desktop Menu Specification"
from freedesktop.org.

%package devel
Summary:        MATE Desktop Menu
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       %{soname}%{sover} = %{version}
Requires:       %{typelib} = %{version}
Requires:       pkgconfig(glib-2.0)
Obsoletes:      python2-mate-menus
Obsoletes:      python-mate-menus

%description devel
mate-menus contains the libmate-menu library, the layout configuration
files for the MATE menu, as well as a simple menu editor.

The libmate-menu library implements the "Desktop Menu Specification"
from freedesktop.org.

%lang_package

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1

%build
NOCONFIGURE=1 mate-autogen
export PYTHON=python2
%configure \
  --disable-static
make %{?_smp_mflags} V=1

%install
%make_install
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{soname}%{sover} -p /sbin/ldconfig

%postun -n %{soname}%{sover} -p /sbin/ldconfig

%files
%if 0%{?suse_version} >= 1500
%license COPYING
%else
%doc COPYING
%endif
%doc ChangeLog README
%dir %{_sysconfdir}/xdg/menus/
%config %{_sysconfdir}/xdg/menus/mate-settings.menu
%config %{_sysconfdir}/xdg/menus/mate-preferences-categories.menu
# Files from branding-upstream.
%exclude %{_sysconfdir}/xdg/menus/mate-applications.menu
%dir %{_datadir}/mate/desktop-directories/
%{_datadir}/mate/desktop-directories/mate-*.directory
%dir %{_datadir}/mate/

%files branding-upstream
%config %{_sysconfdir}/xdg/menus/mate-applications.menu

%files -n %{typelib}
%{_libdir}/girepository-1.0/MateMenu-2.0.typelib

%files -n %{soname}%{sover}
%{_libdir}/%{soname}.so.%{sover}*

%files devel
%{_includedir}/mate-menus/
%{_libdir}/%{soname}.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/gir-1.0/MateMenu-2.0.gir
%dir %{_datadir}/mate-menus/
%{_datadir}/mate-menus/examples/

%files lang -f %{name}.lang

%changelog
* Fri Aug 16 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Fix a crash of mate-menu due to a missing symbol (boo#1144346)
  Add patches from upstream git tree therefore:
  * 0001-drop-python2-support.patch
  * 0002-require-gio-unix.patch
  * 0003-require-gio-unix-drop-python-example.patch
  * 0004-use-G_BEGIN-END_DECLS.patch
  * 0005-backport-from-gnome-menus.patch
  * 0006-udpate-examples.patch
  Remove patches:
  * mate-menus-glib-2.48.patch: not necessary anymore as glib is
    recent enough on Leap 15.x. And it would requires changes on the
    patch series above.
  Remove subpackages:
  * python2-mate-menus and python-mate-menus: dropped in patch series,
    mate-menus examples go to the devel subpackage, which also
    obsoletes the packages.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Require GLib 2.50.
  * Update translations.
- Add mate-menus-glib-2.48.patch: Restore GLib 2.48 support.
- Rename python-mate-menus to python2-mate-menus for
  openSUSE Leap 15.0 and newer.
* Wed Nov  8 2017 sor.alexei@meowr.ru
- Update to version 1.18.1:
  * Make mate-applications-merged/ a symlink to
    applications-merged/.
  * Update translations.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Update translations.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Update translations.
  * Add Changelog generation.
* Mon Jan 25 2016 sor.alexei@meowr.ru
- Update to version 1.13.0:
  * Move preferences-categories.menu from mate-control-center.
    That file can be packaged separately in distros to let users
    decide whether they want categories in preferences menu or not.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0.
- Add baselibs.conf.
* Thu Oct 15 2015 sor.alexei@meowr.ru
- Update to 1.11.0:
  * Use pkg-config to check for Python (requires Python 2.7).
  * Some fixes and cleanups.
  * Update translations.
* Wed Apr 15 2015 p.drouand@gmail.com
- Update to version 1.10.0
  * No changes since version 1.9.90
* Mon Mar 23 2015 p.drouand@gmail.com
- Update to version 1.9.90 (unstable)
  * Translations update
  * Bugfixes
* Tue Nov 11 2014 p.drouand@gmail.com
- Update to version 1.9.1 (unstable)
  + No changelog available
* Sun Oct 26 2014 p.drouand@gmail.com
- Update to version 1.9.0 (unstable)
  + No changelog available
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Wed Feb 19 2014 p.drouand@gmail.com
- Update to version 1.7.90
  + add a possibility to enable old gnome-2 preferences menu style
    with categories
* Sun Jan 19 2014 p.drouand@gmail.com
- Update to version 1.7.1
  + fix some make files for automake-1.13
  + use yelp-tools instead of mate-doc-utils
  + correct invest Icon name
  + back to libwnck
  + replace old gconf with gsettings schema
  + remove Invest_Applet.xml from po/POTFILES.in
    It causes gettext to throw a fit and mateweather applet has a simular
    file and it is also not in POTFILES.in
  + fix make distcheck
  + upate yahoo finance http adress
  + battstat applet: ready for upower-1.0
  + require pygobject 3 now that it was ported to gi
    gobject introspection but this never reflected in configure.ac.
  +  battstat applet: save panel space using an empty label instead of
  - :- when fully charged or unknown
  + initial GTK3 support
- Build with gobject instead of pygtk;
- Build with libwnck support; add libwnck require
* Fri Sep 20 2013 johann.luce@wanadoo.fr
- Fix libraries group System/Libraries
* Wed Apr 10 2013 p.drouand@gmail.com
- Clean up specfile; remove useless *-%%{release} past a "Requires" tag
  & remove useless devel package dependency to main package
* Wed Apr  3 2013 johann.luce@wanadoo.fr
- Update to version 1.6.0
  + Add Recommends:     %%{name}-lang = %%{version}-%%{release}
  + fix incorrect FSF addresses
  + AC_CONFIG_HEADERS to please automake 1.13
  + update translations
* Fri Feb 22 2013 p.drouand@gmail.com
- Remove Requires: mate-menus and add Requires: glib2-devel on devel
  subpackage
* Fri Feb 22 2013 p.drouand@gmail.com
- Add branding subpackage and specific strings
  It is needed to allow to build a external branding
* Wed Nov  7 2012 nmo.marques@gmail.com
- Split typelib and minor cleanups
* Thu Oct 11 2012 nmo.marques@gmail.com
- Update to version 1.5.0
  + no changelog available
  + version bump
* Sat Sep  8 2012 nmo.marques@gmail.com
- copypac to X11:MATE
  + minor cosmetic fixes
* Sat Aug  4 2012 hillwood@linuxfans.org
- Update to version 1.4.0
* Mon Jan  2 2012 fisiu@opensuse.org
- Initial package from version 1.2.0
